# Generated by Django 5.1 on 2024-10-20 03:23

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0018_alter_customer_city'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='customer_group',
            field=models.ForeignKey(default=artd_customer.models.default_customer_group, help_text='Customer group.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customergroup', verbose_name='Customer group'),
        ),
    ]



from django.core.management.base import BaseCommand
from artd_customer.models import MacroTaxSegment, TaxSegment
from artd_location.models import Country
from artd_customer.data.tax_segments import TAX_SEGMENTS


class Command(BaseCommand):
    help = "Create or update MacroTaxSegments and TaxSegments from predefined data"

    def handle(self, *args, **kwargs):
        for segment_data in TAX_SEGMENTS:
            country_id = segment_data["country_id"]
            macro_tax_segment_id = segment_data["macro_tax_segment_id"]
            macro_tax_segment_name = segment_data["macro_tax_segment_name"]
            macro_tax_segment_code = segment_data["macro_tax_segment_code"]
            segments = segment_data["segments"]

            # Obtener o crear el país
            try:
                country = Country.objects.get(id=country_id)
            except Country.DoesNotExist:
                self.stdout.write(
                    self.style.ERROR(f"Country with id {country_id} does not exist.")
                )
                continue

            # Crear o actualizar MacroTaxSegment
            macro_tax_segment, created = MacroTaxSegment.objects.update_or_create(
                id=macro_tax_segment_id,
                defaults={
                    "name": macro_tax_segment_name,
                    "code": macro_tax_segment_code,
                    "country": country,
                },
            )

            if created:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"MacroTaxSegment '{macro_tax_segment_name}' created."
                    )
                )
            else:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"MacroTaxSegment '{macro_tax_segment_name}' updated."
                    )
                )

            # Crear o actualizar los segmentos relacionados (TaxSegments)
            for segment in segments:
                tax_segment_id = segment["tax_segment_id"]
                tax_segment_name = segment["tax_segment_name"]
                tax_segment_code = segment["tax_segment_code"]

                tax_segment, created = TaxSegment.objects.update_or_create(
                    id=tax_segment_id,
                    defaults={
                        "name": tax_segment_name,
                        "code": tax_segment_code,
                        "macrosegment": macro_tax_segment,
                    },
                )

                if created:
                    self.stdout.write(
                        self.style.SUCCESS(f"TaxSegment '{tax_segment_name}' created.")
                    )
                else:
                    self.stdout.write(
                        self.style.SUCCESS(f"TaxSegment '{tax_segment_name}' updated.")
                    )

        self.stdout.write(
            self.style.SUCCESS(
                "All MacroTaxSegments and TaxSegments have been processed."
            )
        )



# Generated by Django 5.1 on 2024-10-20 02:48

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0013_customerdocumenttype_customerpersontype_customertype'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customer',
            name='customer_person_type',
        ),
        migrations.RemoveField(
            model_name='customer',
            name='customer_type',
        ),
        migrations.RemoveField(
            model_name='customer',
            name='document_type',
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2024, 10, 20, 2, 48, 36, 404342, tzinfo=datetime.timezone.utc), help_text='Date time on which the object was created.', verbose_name='Created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='external_id',
            field=models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='source',
            field=models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='status',
            field=models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at'),
        ),
    ]



# Generated by Django 5.1 on 2024-10-20 03:16

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0016_alter_customer_customer_person_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='tax_segment',
            field=models.ForeignKey(default=artd_customer.models.get_tax_segment, help_text='Tax segment.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.taxsegment', verbose_name='Tax segment'),
        ),
    ]



# Generated by Django 5.1 on 2024-10-20 01:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0012_customer_vat_responsible'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomerDocumentType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='Name of the customer document type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer document type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Document Type',
                'verbose_name_plural': 'Customer Document Types',
            },
        ),
        migrations.CreateModel(
            name='CustomerPersonType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the customer person type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer person type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Person Type',
                'verbose_name_plural': 'Customer Person Types',
            },
        ),
        migrations.CreateModel(
            name='CustomerType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the customer type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Type',
                'verbose_name_plural': 'Customer Types',
            },
        ),
    ]



# Generated by Django 5.1 on 2024-10-19 13:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0009_customergroup_partner'),
        ('artd_location', '0002_alter_city_created_at_alter_city_status_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='MacroTaxSegment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the macroTaxSegment.', max_length=250, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the macrosegment.', max_length=250, verbose_name='Code')),
                ('country', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='artd_location.country')),
            ],
            options={
                'verbose_name': 'MacroTaxSegment',
                'verbose_name_plural': 'Macrosegments',
            },
        ),
        migrations.CreateModel(
            name='TaxSegment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the taxSegment.', max_length=250, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the taxSegment.', max_length=250, verbose_name='Code')),
                ('macrosegment', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='artd_customer.macrotaxsegment')),
            ],
            options={
                'verbose_name': 'TaxSegment',
                'verbose_name_plural': 'TaxSegments',
            },
        ),
        migrations.AddField(
            model_name='customer',
            name='tax_segment',
            field=models.ForeignKey(blank=True, help_text='Tax segment.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.taxsegment', verbose_name='Tax segment'),
        ),
    ]



from django.utils.translation import gettext_lazy as _

CUSTOMER_TYPES = [
    {
        "code": "customer",
        "name": "Customer",
    },
    {
        "code": "supplier",
        "name": "Supplier",
    },
    {
        "code": "other",
        "name": "Other",
    },
]

CUSTOMER_PERSON_TYPES = [
    {
        "code": "person",
        "name": "Person",
    },
    {
        "code": "company",
        "name": "Company",
    },
]

DOCUMENT_TYPES = [
    {
        "code": "dni",
        "name": "DNI",
    },
    {
        "code": "nit",
        "name": "NIT",
    },
    {
        "code": "passport",
        "name": "Passport",
    },
    {
        "code": "passport",
        "name": "Passport",
    },
    {
        "code": "Foreigners_id:_card",
        "name": "Foreigner's ID card",
    },
    {
        "code": "license",
        "name": "License",
    },
    {
        "code": "other",
        "name": "Other",
    },
]



# Generated by Django 5.1 on 2024-10-20 03:20

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0017_alter_customer_tax_segment'),
        ('artd_location', '0002_alter_city_created_at_alter_city_status_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='city',
            field=models.ForeignKey(default=artd_customer.models.get_default_city, help_text='City of the customer.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_location.city', verbose_name='City'),
        ),
    ]



from django.core.management.base import BaseCommand
from artd_customer.models import CustomerGroup
from artd_partner.models import Partner

CUSTOMER_GROUPS = [
    {
        "group_code": "new",
        "group_name": "New customers",
        "description": "New customers",
    },
    {
        "group_code": "wholesale",
        "group_name": "Wholesale customers",
        "description": "Wholesale customers",
    },
    {
        "group_code": "vip",
        "group_name": "VIP customers",
        "description": "VIP customers",
    },
]


class Command(BaseCommand):
    help = "Create the base customer groups."

    def add_arguments(self, parser):
        parser.add_argument(
            "--partner_slug",
            type=str,
            help="Slug of the partner",
            default=None,
        )

    def handle(self, *args, **options):
        partner_slug = options["partner_slug"]
        print(partner_slug)
        if partner_slug:
            complement = f"_{partner_slug}"
        else:
            complement = ""
        for group in CUSTOMER_GROUPS:
            try:
                if (
                    CustomerGroup.objects.filter(
                        group_code=group["group_code"] + complement,
                        partner__partner_slug=partner_slug,
                    ).count()
                    == 0
                ):
                    customer_group = CustomerGroup.objects.create(
                        group_code=group["group_code"] + complement,
                        group_name=group["group_name"] + complement,
                        group_description=group["description"],
                    )
                    if partner_slug:
                        partner = Partner.objects.filter(
                            partner_slug=partner_slug
                        ).last()
                        if partner:
                            customer_group.partner = partner
                            customer_group.save()
                        else:
                            self.stdout.write(
                                self.style.ERROR(f"Partner {partner_slug} not found")
                            )
                    self.stdout.write(
                        self.style.WARNING(
                            f'Customer group {group["group_code"]} created'
                        )
                    )
                else:
                    if partner_slug:
                        partner = Partner.objects.filter(
                            partner_slug=partner_slug
                        ).last()
                        if partner:
                            customer_group = CustomerGroup.objects.filter(
                                group_code=group["group_code"] + complement,
                                partner=partner,
                            ).last()
                            customer_group.group_name = group["group_name"] + complement
                            customer_group.group_description = group["description"]
                            customer_group.save()
                        else:
                            self.stdout.write(
                                self.style.ERROR(f"Partner {partner_slug} not found")
                            )

                    else:
                        customer_group = CustomerGroup.objects.filter(
                            group_code=group["group_code"] + complement
                        ).last()
                        customer_group.group_name = group["group_name"] + complement
                        customer_group.group_description = group["description"]
                        customer_group.save()
                    self.stdout.write(
                        self.style.ERROR(
                            f'Customer group {group["group_code"]} updated'
                        )
                    )
            except Exception as e:
                self.stdout.write(self.style.ERROR(f"Error: {e}"))



# Generated by Django 5.1 on 2024-10-20 01:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0011_customer_customer_person_type_customer_customer_type_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='vat_responsible',
            field=models.BooleanField(default=False, help_text='VAT responsible', verbose_name='VAT responsible'),
        ),
    ]



from django.core.management.base import BaseCommand
from artd_customer.models import (
    CustomerType,
    CustomerPersonType,
    CustomerDocumentType,
)
from artd_customer.data.cutomer_vat import (
    CUSTOMER_TYPES,
    CUSTOMER_PERSON_TYPES,
    DOCUMENT_TYPES,
)


class Command(BaseCommand):
    help = "Create or update CustomerType, CustomerPersonType and CustomerDocumentType"

    def handle(self, *args, **kwargs):
        for customer_type in CUSTOMER_TYPES:
            obj, created = CustomerType.objects.update_or_create(
                code=customer_type["code"],
                defaults={
                    "name": customer_type["name"],
                },
            )
            if created:
                self.stdout.write(
                    self.style.SUCCESS(f"CustomerType created: {obj.code} - {obj.name}")
                )
            else:
                self.stdout.write(
                    self.style.SUCCESS(f"CustomerType updated: {obj.code} - {obj.name}")
                )

        for customer_person_type in CUSTOMER_PERSON_TYPES:
            obj, created = CustomerPersonType.objects.update_or_create(
                code=customer_person_type["code"],
                defaults={
                    "name": customer_person_type["name"],
                },
            )
            if created:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"CustomerPersonType created: {obj.code} - {obj.name}"
                    )
                )
            else:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"CustomerPersonType updated: {obj.code} - {obj.name}"
                    )
                )

        for document_type in DOCUMENT_TYPES:
            obj, created = CustomerDocumentType.objects.update_or_create(
                code=document_type["code"],
                defaults={
                    "name": document_type["name"],
                },
            )
            if created:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"CustomerDocumentType created: {obj.code} - {obj.name}"
                    )
                )
            else:
                self.stdout.write(
                    self.style.SUCCESS(
                        f"CustomerDocumentType updated: {obj.code} - {obj.name}"
                    )
                )



TAX_SEGMENTS = [
    {
        "country_id": 45,
        "macro_tax_segment_id": 1,
        "macro_tax_segment_name": "Grandes contribuyentes",
        "macro_tax_segment_code": "grandes_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 1,
                "tax_segment_name": "Grandes contribuyentes",
                "tax_segment_code": "grandes_contribuyentes",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 2,
        "macro_tax_segment_name": "Medianos contribuyentes",
        "macro_tax_segment_code": "medianos_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 2,
                "tax_segment_name": "Medianos",
                "tax_segment_code": "medianos",
            },
            {
                "tax_segment_id": 3,
                "tax_segment_name": "Medianos altos",
                "tax_segment_code": "medianos_altos",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 3,
        "macro_tax_segment_name": "Pequeños contribuyentes",
        "macro_tax_segment_code": "pequeños_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 4,
                "tax_segment_name": "Micro contribuyentes",
                "tax_segment_code": "micro_contribuyentes",
            },
            {
                "tax_segment_id": 5,
                "tax_segment_name": "Pequeños contribuyentes",
                "tax_segment_code": "pequenos_contribuyentes",
            },
            {
                "tax_segment_id": 6,
                "tax_segment_name": "Personas Jurídicas no declarantes",
                "tax_segment_code": "personas_juridicas_no_declarantes",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 4,
        "macro_tax_segment_name": "Personas Naturales",
        "macro_tax_segment_code": "personas_naturales",
        "segments": [
            {
                "tax_segment_id": 7,
                "tax_segment_name": "Personas Naturales declarantes",
                "tax_segment_code": "personas_naturales_declarantes",
            },
            {
                "tax_segment_id": 8,
                "tax_segment_name": "Personas Naturales no declarantes",
                "tax_segment_code": "personas_naturales_no_declarantes",
            },
        ],
    },
]



# Generated by Django 5.1 on 2024-10-20 02:50

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0015_customer_customer_person_type_customer_customer_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='customer_person_type',
            field=models.ForeignKey(default=artd_customer.models.get_default_customer_person_type, help_text='Customer person type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customerpersontype', verbose_name='Customer person type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='customer_type',
            field=models.ForeignKey(default=artd_customer.models.get_default_customer_type, help_text='Customer type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customertype', verbose_name='Customer type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='document_type',
            field=models.ForeignKey(default=artd_customer.models.customer_document_type, help_text='Document type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customerdocumenttype', verbose_name='Document type'),
        ),
    ]



# Generated by Django 5.1 on 2024-10-19 22:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0010_macrotaxsegment_taxsegment_customer_tax_segment'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='customer_person_type',
            field=models.CharField(choices=[('person', 'Person'), ('company', 'Company')], default='person', help_text='Customer person type', max_length=50, verbose_name='Customer person type'),
        ),
        migrations.AddField(
            model_name='customer',
            name='customer_type',
            field=models.CharField(choices=[('customer', 'Customer'), ('supplier', 'Supplier'), ('other', 'Other')], default='customer', help_text='Customer type', max_length=50, verbose_name='Customer type'),
        ),
        migrations.AddField(
            model_name='customer',
            name='document_type',
            field=models.CharField(choices=[('dni', 'DNI'), ('nit', 'NIT'), ('passport', 'Passport'), ('passport', 'Passport'), ('Foreigners_id:_card', "Foreigner's ID card"), ('license', 'License'), ('other', 'Other')], default='dni', help_text='Document type', max_length=50, verbose_name='Document type'),
        ),
    ]
